@@ -1,4 +1,5 @@
-modified_base.F <- function(Feat, SQuali, SQualiN){
+modified_base.F <-
+function(Feat, SQuali, SQualiN){
   Item <- c("/allele=", "/citation=", "/db_xref=", "/experiment=", "/frequency=", "/gene=", "/gene_synonym=", "/inference=", "/locus_tag=", "/map=", "/mod_base=", "/note=", "/old_locus_tag=")
   ItemN <- c("allele", "citation", "db_xref", "experiment", "frequency", "gene", "gene_synonym", "inference", "locus_tag", "map", "mod_base", "note", "old_locus_tag")
   Feat[length(Feat)] <- gsub("\\\",$", "", Feat[length(Feat)])
