@@ -1,4 +1,5 @@
-oriT.F <- function(Feat, SQuali, SQualiN){
+oriT.F <-
+function(Feat, SQuali, SQualiN){
   Item <- c("/allele=", "/bound_moiety=", "/citation=", "/db_xref=", "/direction=", "/experiment=", "/gene=", "/gene_synonym=", "/inference=", "/locus_tag=", "/map=", "/note=", "/old_locus_tag=", "/rpt_family=", "/rpt_type=", "/rpt_unit_range=", "/rpt_unit_seq=", "/standard_name=")
   ItemN <- c("allele", "bound_moiety", "citation", "db_xref", "direction", "experiment", "gene", "gene_synonym", "inference", "locus_tag", "map", "note", "old_locus_tag", "rpt_family", "rpt_type", "rpt_unit_range", "rpt_unit_seq", "standard_name")
   Feat[length(Feat)] <- gsub("\\\",$", "", Feat[length(Feat)])
