@@ -1,7 +1,7 @@
 #' @title Opens files with .gb extensions
-#' 
+#'
 #' @description This function opens complete record(s) with .gb extension from the NCBI/GenBank Nucleotide database and returns a list containing shaped record(s). These kind of files contains detailed records of DNA samples (locus, organism, type of sequence, source of the sequence...). An example of record can be found at <https://www.ncbi.nlm.nih.gov/nuccore/HE799070>. Records with > 200'000 bp may experience long processing times, especially if they have numerous FEATURES items. Also works for reports obtained with rentrez package.
-#'  
+#'
 #'
 #' @param x  character. The name of the file which the data are to be read from, or the character string containing the data. It can contains several records
 #' @param DNA   logical. If TRUE, the DNA sequence in the ORIGIN part will be merged in one character string. If FALSE, the default layout will be kept. Default if TRUE
@@ -15,17 +15,23 @@
 #'
 #' @return Returns a table containing the data
 #'
+#' @importFrom rentrez entrez_fetch
+#'
 #' @examples
 #' \dontrun{
 #' read.gb(File = "sequence.gb", DNA = TRUE, Type = "full", Source = "File")
 #' }
-#' 
+#'
+#' \dontrun{
 #' require(rentrez)
-#' x <- rentrez::entrez_fetch(db = "Nucleotide", id = "508082122", rettype = "gb")
-#' read.gb(File = x, DNA = TRUE, Type = "full", Source = "Char")
-#' 
+#' data <- rentrez::entrez_fetch(db = "Nucleotide", id = "508082122", rettype = "gb")
+#' read.gb(File = data, DNA = TRUE, Type = "full", Source = "Char")
+#' }
+#'
 #' @export
-read.gb <- function(x, DNA = TRUE, Type = "full", Source = "File"){
+#'
+read.gb <-
+function(x, DNA = TRUE, Type = "full", Source = "File"){
   ## Source of data :
   if(Source == "File"){
     Base <- readChar(x, file.info(x)$size, nchars = 99999999)
@@ -34,9 +40,12 @@ read.gb <- function(x, DNA = TRUE, Type = "full", Source = "File"){
     Base <- x
   }
 
+  ## Separation of reports :
   Sample <- list()
-  SampleS <- gregexpr("LOCUS", Base)[[1]]
+  SampleS <- gregexpr("LOCUS {2,}", Base)[[1]]
   SampleE <- gregexpr("(?<!:)//", Base, perl = T)[[1]]
+
+  ## Treatment of reports
   for(k in 1:length(SampleS)){
     Temp <- substr(Base, SampleS[k], SampleE[k])
     y <- Reorganize.report(Temp)
