@@ -1,4 +1,5 @@
-telomere.F <- function(Feat, SQuali, SQualiN){
+telomere.F <-
+function(Feat, SQuali, SQualiN){
   Item <- c("/citation=", "/db_xref=", "/experiment=", "/inference=", "/note=","/rpt_type=", "/rpt_unit_range=", "/rpt_unit_seq=", "/standard_name=")
   ItemN <- c("citation", "db_xref", "experiment", "inference", "note","rpt_type", "rpt_unit_range", "rpt_unit_seq", "standard_name")
   Feat[length(Feat)] <- gsub("\\\",$", "", Feat[length(Feat)])
